@@ -1,6 +1,6 @@
 /***************************************************************************
   UndoReverseAction.cpp  -  undo action for the "reverse" effect
-			     -------------------
+                             -------------------
     begin                : Wed Jun 24 2009
     copyright            : (C) 2009 by Thomas Eschenbacher
     email                : Thomas Eschenbacher <Thomas.Eschenbacher@gmx.de>
@@ -59,7 +59,7 @@ qint64 Kwave::UndoReverseAction::redoSize()
 //***************************************************************************
 bool Kwave::UndoReverseAction::store(Kwave::SignalManager &manager)
 {
-    Q_UNUSED(manager);
+    Q_UNUSED(manager)
     return true;
 }
 
@@ -67,9 +67,9 @@ bool Kwave::UndoReverseAction::store(Kwave::SignalManager &manager)
 Kwave::UndoAction *Kwave::UndoReverseAction::undo(Kwave::SignalManager &manager,
                                                   bool with_redo)
 {
-    Q_UNUSED(manager);
+    Q_UNUSED(manager)
     m_plugin_manager.enqueueCommand(
-	_("nomacro:plugin:execute(reverse,noundo)")
+        _("nomacro:plugin:execute(reverse,noundo)")
     );
     return (with_redo) ? this : Q_NULLPTR;
 }
